/* ---------------------------------------------------------------------- */
/* Fix file for installing TE/2 Pro Online Registration Aids component on */
/* Warp 3.                                                                */
/* This file is copyright (c) 1997 by Oberon Software, Inc., Mankato, MN  */
/* Permission is hereby granted for use of this file in conjunction with  */
/* the installation of TE/2 Pro Version 2.1 and for the redistribution of */
/* this file to any and all interested parties so long a it is            */
/* redistributed in its entirety and is not modified.                     */
/* ---------------------------------------------------------------------- */

/* ---------------------------------------------------------------------- */
/*                       HOW TO USE THIS PROGRAM                          */
/*                                                                        */
/* If you are running OS/2 Warp 3 or earlier and have been unsuccessful   */
/* installing TE/2 Pro Version 2.1, this is because the TE/2 Pro install  */
/* has attempted to create some OS/2 Warp 4 specific URL objects.  This   */
/* program will create the OS/2 Warp 3 equivalents of these objects.      */
/*                                                                        */
/* The procedure is as follows:                                           */
/*   1. Install TE/2 Pro Version 2.1 but DO NOT select the componant      */
/*   named 'TE/2 Pro! Registration Aids' before you select the "Install"  */
/*   button.                                                              */
/*   2. While the TE/2 Pro distribution diskette is still in the floppy   */
/*   drive (or the installation files are still on your hardisk if you    */
/*   installing in that manner), execute this program with two command    */
/*   line parameters:  The path the the installation files, and the path  */
/*   to the directory in which you installed TE/2 Pro.  Examples:         */
/*                                                                        */
/*                  InsWarp3 A: C:\TE2PRO                                 */
/*                  InsWarp3 F:\TEMP D:\TE2PRO                            */
/*                                                                        */
/* ---------------------------------------------------------------------- */

/* ---------------------------------------------------------------------- */
/* Note: This program is distributed, free of charge, by Oberon Software. */
/* Oberon Software does not warrant it to be free from defect nor that    */
/* it will work in all situations.  As always, please backup any working  */
/* installation of TE/2 Pro before applying this fix.  Use this program   */
/* at your own risk; your use of this program constitutes your agreement  */
/* to these terms.                                                        */
/* ---------------------------------------------------------------------- */


'@echo off'

/* Load REXXUTIL */
call RxFuncAdd 'SysLoadFuncs','RexxUtil','SysLoadFuncs'
signal on Syntax Name LoadCheck
call SysLoadFuncs
LoadCheck: /* rc of 43 means REXXUTILs not found */
if rc=43 then do
   say ''
   say 'ERROR: Not able to load REXXUTILs. Perhaps REXX not installed or'
   say '       REXXUTIL.DLL not found in a LIBPATH drive/directory.'
   exit 1
end
signal off Syntax

/* Get command line and init global vars */
parse arg instPath te2proPath warp4 .
ok2process = 'NO'
object.  = ''
object.0 = 0
unpack   = ''
unpack.0 = 0
copy.    = ''
copy.0   = 0
if translate(warp4) = 'WARP4' then
  do
    URLType    = 'WPUrl'
    URLSetting = 'URL'
  end
else
  do
    URLType    = 'WebExplorer_Url'
    URLSetting = 'LOCATOR'        
  end

/* check command line and issue help message if not correct */
if length(instPath) = 0 | length(te2proPath) = 0 then
  call Help
else
  do
    if CheckTarget() = 0 then
      call Help
    else
      do
        call Setup
        if ok2process = 'YES' then call Process
      end
  end

exit 0

Help:
  say 'usage: InsWarp3 installpath te2propath [WARP4]'
  say '  "packagefile" is full pathname to TE/2 installation files.'
  say '  "te2proPath"  is full pathname where TE/2 Pro is installed.'
  say '  "WARP4"       is optional.  If it is included and is the'
  say '                string "WARP4", then Warp 4 WPUrl type objects'
  say '                will be created instead of Warp 3 WebExplorer_Url'
  say '                type objects.'
  say ''
  say 'Examples:'
  say '  InsWarp3 A: C:\TE2PRO'
  say '  InsWarp3 F:\TEMP D:\TE2PRO'
  say ''
  return


CheckTarget:
  isOK = 0
  savePath = directory()
  newPath = directory(te2proPath)
  if length(newPath) > 0 then
    do
      te2proPath = newPath
      isOK = 1
    end
  call directory savePath
  return isOK


Setup:
  /* Check to see if the files we need to copy or unpack are there */
  /* Even if they are not, we will still give the go-ahead to      */
  /* create the URL objects.                                       */

  /* First, setup the folder for these items. */
  object.0 = 1
  object.1.type     = 'WPFolder'
  object.1.title    = 'Online Registration^and Information'
  object.1.location = '<OBERON_TE2PROFOLDER>'
  object.1.setup    = 'OBJECTID=<OBERON_TE2PROREGFOLDER>'
  object.1.flag     = 'R'

  /* now check for unpacked and copied files */
  r = stream(instPath||'\README.OR@', 'C', 'query exists')
  if length(r) > 0 then
    do
      i = unpack.0 + 1
      unpack.0 = i
      unpack.i.src  = r
      unpack.i.targ = te2proPath
      i = object.0 + 1
      object.0 = i
      object.i.type     = 'WPShadow'
      object.i.title    = 'README.ORD'
      object.i.location = '<OBERON_TE2PROREGFOLDER>'
      object.i.setup    = 'OBJECTID=<OBERON_TE2PROREADORD>;SHADOWID='te2proPath'\README.ORD;'
      object.i.flag     = 'R'
    end

  r = stream(instPath||'\PURCHASE.EX@', 'C', 'query exists')
  if length(r) > 0 then
    do
      i = unpack.0 + 1
      unpack.0 = i
      unpack.i.src  = r
      unpack.i.targ = te2proPath
      i = object.0 + 1
      object.0 = i
      object.i.type     = 'WPProgram'
      object.i.title    = 'BMT Micro^Online Ordering'
      object.i.location = '<OBERON_TE2PROREGFOLDER>'
      object.i.setup    = 'OBJECTID=<OBERON_TE2PROBMTORD>;PROGTYPE=PM;EXENAME='te2proPath'\PURCHASE.EXE;STARTUPDIR='te2proPath';'
      object.i.flag     = 'R'
    end

  r = stream(instPath||'\PURCHASE.APP', 'C', 'query exists')
  if length(r) > 0 then
    do
      i = copy.0 + 1
      copy.0 = i
      copy.i = r
      copy.i.src  = r
      copy.i.targ = te2proPath
    end

  r = stream(instPath||'\PURCHASE.IC@', 'C', 'query exists')
  if length(r) > 0 then
    do
      i = unpack.0 + 1
      unpack.0 = i
      unpack.i = r
      unpack.i.src  = r
      unpack.i.targ = te2proPath
    end

  /* Now build the URLs */
  i = object.0 + 1
  object.0 = i
  object.i.type = URLType
  object.i.title    = 'Oberon Software, Inc.^WWW Page'
  object.i.location = '<OBERON_TE2PROREGFOLDER>'
  object.i.setup    = 'OBJECTID=<OBERON_TE2PROOBURL>;'URLSetting'=http://prairie.lakes.com/~oberon/;'
  object.i.flag     = 'R'
  i = object.0 + 1
  object.0 = i
  object.i.type = URLType
  object.i.title    = 'BMT Micro^WWW Page'
  object.i.location = '<OBERON_TE2PROREGFOLDER>'
  object.i.setup    = 'OBJECTID=<OBERON_TE2PROBMTURL>;'URLSetting'=http://www.bmtmicro.com/;'
  object.i.flag     = 'R'
  i = object.0 + 1
  object.0 = i
  object.i.type = URLType
  object.i.title    = 'IBM Desktop Direct^WWW Page'
  object.i.location = '<OBERON_TE2PROREGFOLDER>'
  object.i.setup    = 'OBJECTID=<OBERON_TE2PROIBMURL>;'URLSetting'=http://ibm-direct.e-com.ibm.com/us/;'
  object.i.flag     = 'R'
  i = object.0 + 1
  object.0 = i
  object.i.type = URLType
  object.i.title    = 'Indelible Blue, Inc.^WWW Page'
  object.i.location = '<OBERON_TE2PROREGFOLDER>'
  object.i.setup    = 'OBJECTID=<OBERON_TE2PROIBURL>;'URLSetting'=http://www.webpress.net/ib/;'
  object.i.flag     = 'R'
  i = object.0 + 1
  object.0 = i
  object.i.type = URLType
  object.i.title    = 'Norloff''s OS/2 BBS^WWW Page'
  object.i.location = '<OBERON_TE2PROREGFOLDER>'
  object.i.setup    = 'OBJECTID=<OBERON_TE2PROPNURL>;'URLSetting'=http://www.os2bbs.com/;'
  object.i.flag     = 'R'

  ok2process = 'YES'
  return

Process:
  if copy.0 > 0 then call CopyFiles
  if unpack.0 > 0 then call UnpackFiles
  if object.0 > 0 then call CreateObjects
  return

CopyFiles:
  do i = 1 to copy.0
    say 'copy' copy.i.src copy.i.targ
    'copy' copy.i.src copy.i.targ
  end
  return

UnpackFiles:
  do i = 1 to unpack.0
    say 'unpack' unpack.i.src unpack.i.targ
    'unpack' unpack.i.src unpack.i.targ
  end
  return

CreateObjects:
  do i = 1 to object.0
    call charout , 'Creating' object.i.type 'object"'object.i.title'"...'
    r = SysCreateObject(object.i.type, object.i.title, object.i.location, object.i.setup, object.i.flag)
    if r = 1 then call charout ,'   Done!'
    else          call charout ,'   Not created! Return code='r
    say ''
  end
  return
